<template>
  <div>
    <ttable
      :table="table"
      :uploadInfo="{
        isShow: false
      }"
      :paramObj="{
        queryType: 0
      }"
      :options="options"
      :ajaxFun="ajaxFun"
      :bottomOffset="80"
      @currentChange="(row) => (currentRow = row)"
      ref="reportTableNewTab1"
    >
      <template #toolbar />
    </ttable>
  </div>
</template>

<script>
import { fetchList } from '@/api/quality/newReport'
import { remote } from '@/api/admin/dict'
import { mapGetters } from 'vuex'
import ttable from '@/views/common/ztt-table.vue'

export default {
  data() {
    const tt = (prop, label, config) => {
      const w = (label.length - 1) * 20 + 15
      return Object.assign(
        {
          minWidth: w,
          width: w < 110 ? 110 : w,
          prop,
          label,
          sort: true,
          isTrue: true,
          isSearch: true,
          searchInfoType: 'text'
        },
        config
      )
    }
    return {
      ajaxFun: fetchList,
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: false, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'applyNo', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          tt('applyNo', '申请编号'),
          tt('applyType', '申请类型', {
            searchInfoType: 'select',
            formatter: (row, column, cellValue) => {
              const i = this.applyTypeList.find((e) => e.value === cellValue)
              return i ? i.label : ''
            },
            optList: () => {
              return this.applyTypeList
            }
          }),
          tt('moNo', '车间订单号'),
          tt('systemNo', '系统号'),
          tt('reelNumber', '载具编号'),
          tt('outBatchNo', 'SN号'),
          tt('partNo', '零件号'),
          tt('partName', '零件名称'),
          tt('totalLength', '报检长度'),
          tt('operationName', '工序'),
          tt('workstationName', '机台'),
          tt('produceUser', '生产人员'),
          tt('applyTime', '报检时间', {
            searchInfoType: 'datetimerange'
          }),
          tt('applyUser', '报检人员')
        ],
        toolbar: [
          {
            text: '创建汇报',
            type: 'primary',
            fun: this.goAdd
          }
        ]
      },
      applyTypeList: [],
      currentRow: null
    }
  },
  components: {
    ttable
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    remote('apply_report_type').then((response) => {
      if (response.data.code === 0) {
        this.applyTypeList = response.data.data
      } else {
        this.applyTypeList = []
      }
    })
  },

  activated() {},
  methods: {
    // 获取数据列表
    getData() {
      return this.$refs.reportTableNewTab1.getDataList()
    },
    goAdd(row) {
      if (!this.currentRow) {
        this.$message.warning('请选择待检零件')
      } else {
        sessionStorage.setItem(
          'ztt-newReportRow',
          JSON.stringify(this.currentRow)
        )
        this.$router.push({
          name: 'newReportForm',
          query: {
            type: 'add'
          }
        })
      }
    }
  }
}
</script>
